# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [0.1.2] - 2025-12-19

### Changed

- Internal change: Switched project management from hatch to uv.

### Fixed

- Fix private import type error for downstream packages with strict type checks.

## [0.1.1] - 2025-04-11

### Fixed

- Fix broken package typing from missing marker file.


## [0.1.0] - 2024-07-30
- Initial release.


[0.1.2]: https://github.com/brews/muuttaa/compare/v0.1.1...v0.1.2
[0.1.1]: https://github.com/brews/muuttaa/compare/v0.1.0...v0.1.1
[0.1.0]: https://github.com/brews/muuttaa/releases/tag/v0.1.0
